@@ -12,10 +12,10 @@ __all__ = [
 ]
 
 __title__ = 'pydash'
-__summary__ = 'Python port of Lodash'
+__summary__ = 'Python port of Lo-Dash'
 __url__ = 'https://github.com/dgilland/pydash'
 
-__version__ = '0.0.0'
+__version__ = '1.0.0'
 
 __author__ = 'Derrick Gilland'
 __email__ = 'dgilland@gmail.com'
